import { createStorefrontApiClient } from '@shopify/storefront-api-client';
import { REACT_APP_ACCESS_TOKEN, REACT_APP_SHOP_NAME } from '../utils/httpCommon'

const defaultQuery = 'status:active, product_type:clothing, product_categroy:dresses';
const defaultResult = 250;
const defaultSortBy = 'TITLE';

const client = createStorefrontApiClient({
  storeDomain: `https://${REACT_APP_SHOP_NAME}/api/2024-10/graphql.json`,
  apiVersion: '2024-10',
  publicAccessToken: REACT_APP_ACCESS_TOKEN,
});

// getProduct(5, CREATED_AT, 'product_type:clothing'); 
const getProducts = async (maxResults = defaultResult, sortBy = defaultSortBy, customQuery = defaultQuery) => {

  const query = `{
    products(first: ${maxResults}, query: "${customQuery}", sortKey:${sortBy}) {
      nodes {
        id
        title
        productType
        compareAtPriceRange {
          maxVariantPrice {
            amount
            currencyCode
          }
          minVariantPrice {
            amount
            currencyCode
          }
        }
        images(first: 4) {
          nodes {
            src
            url
          }
        }
        collections(first: 55) {
          nodes {
            title
          }
        }
        variants(first: 200) {
          nodes {
            id
            title
            price {
              amount
              currencyCode
            }
          }
        }
      }
      pageInfo {
        hasNextPage
        hasPreviousPage
      }
    }
  }`

  const { data, errors, extensions } = await client.request(query, {
    variables: {
      handle: 'sample-product',
    },
  });

  debugger

  return data.products.nodes

}

const getProduct = async (id = "") => {

  const query = `{
    product(id: "gid://shopify/Product/${id}") {
      id
      title
      descriptionHtml
      productType
      compareAtPriceRange {
        maxVariantPrice {
          currencyCode
          amount
        }
        minVariantPrice {
          amount
          currencyCode
        }
      }
      images(first: 4) {
        nodes {
          src
          url
        }
      }
      variants(first: 200) {
        nodes {
          id
          title
          price {
            amount
            currencyCode
          }
          selectedOptions {
            name
            value
          }
          quantityAvailable
        }
      }
      collections(first: 20) {
        nodes {
          title
        }
      }
    }
  }`

  const { data, errors, extensions } = await client.request(query, {
    variables: {
      handle: 'sample-product',
    },
  });

  return data.product

}

const getProductTypes = async () => {
  const query = `{
    productTypes(first: 250) {
      edges {
        node
      }
    }  
  }`

  const { data, errors, extensions } = await client.request(query, {
    variables: {},
  });

  return data.productTypes.edges
}

const getCollections = async (name) => {

  const query = `{
    products(first: 250, query: "product_type:${name}") {
      nodes {
        createdAt
        productType
        collections(first: 1) {
          nodes {
            title
            id
            image {
              src
            }
          }
        }
      }
    }
  }`

  const { data, errors, extensions } = await client.request(query, {
    variables: {},
  });

  const uniqueCollections = new Map();

  // Iterate through all products
  data.products.nodes.forEach((product) => {
    // Iterate through each collection within a product
    product.collections.nodes.forEach((collection) => {
      const { title, id, image } = collection;

      // Use the collection ID as a unique key to avoid duplicates
      if (!uniqueCollections.has(id)) {
        uniqueCollections.set(id, {
          name: title,
          id,
          src: image ? image.src : null, // Handle null image gracefully
        });
      }
    });
  });

  return Array.from(uniqueCollections.values());

}

const ProductService = {
  getProducts,
  getProduct,
  getProductTypes,
  getCollections
}

export default ProductService
